clear all
F0=20570;xfN2=0.23251;xfH2=0.62981;xfNH3=0.03826;
Pt=2.786e7; % Pa
R=8.314;
[X, T]=meshgrid(1:1:30,250:5:450);
% Extent of reaction
kc=F0*(X/100-xfNH3)./(1+X/100);
% Partial pressue of components
PNH3=X/100*Pt;
PN2=(F0*xfN2-0.5*kc)./(F0-kc)*Pt;
PH2=(F0*xfH2-1.5*kc)./(F0-kc)*Pt;
Rk=2.923e-8.*exp(-91000./(R.*(T+273.15))).*PN2.^0.5.*PH2.^1.5-3.85e3.*...
    exp(-140000./(R.*(T+273.15))).*PNH3;

%figure
%surf(X,T,Rk);
%axis([1,30,250,450,0,15]);
%xlabel('NH3 Conc. (%)')
%ylabel('Temperature (oC)')
%zlabel('Rk (kmol/m3 s)')

figure
[c1,h1]=contour(X,T,Rk,[0,.01,.03,.1,.3],'k-','LineWidth',2);
clabel(c1,h1,'LabelSpacing',220);
xlabel('NH3 Conc. (%)')
ylabel('Temperature (oC)')

phy1=0.1; phy2=0.1; phy3=0.1;
disp('Please Wait');
% Define Aspen Plus server
aspen=actxserver('Apwn.Document');
% Define the path of Aspen Plus file
path=char(string('F:\personal\Lectures\Petrochemical Processes\')+...
    string('lectures_PP\lecture 10_Optimization\Ammonia_Optim.bkp'));
aspen.InitFromArchive2(path);
%aspen.Activate(); % Optional
% Transfer the inputs to Aspen Plus
aspen.Tree.FindNode('\Data\Streams\MAKEUP\Input\PRES\MIXED').Value=Pt/1.013e5;
aspen.Tree.FindNode('\Data\Streams\RECYCLE\Input\PRES\MIXED').Value=Pt/1.013e5;
aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Input\FRAC\F2').Value=phy1;
aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Input\FRAC\F3').Value=phy2;
aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Input\FRAC\F4').Value=phy3;
% Run Aspen Plus file
disp('run started'); %Optional
aspen.Engine.Run2()
disp('run finished'); %Optional
% Transfer the results from Aspen Plus (In this example the Temp and Conc
% profle in each bed and optimal split fraction)
for cnt=1:11
    path=char(string('\Data\Blocks\BED1\Output\B_TEMP\MIXED\')+string(cnt));
    Tbed1(cnt)=aspen.Tree.FindNode(path).Value;
    path=char(string('\Data\Blocks\BED2\Output\B_TEMP\MIXED\')+string(cnt));
    Tbed2(cnt)=aspen.Tree.FindNode(path).Value;
    path=char(string('\Data\Blocks\BED3\Output\B_TEMP\MIXED\')+string(cnt));
    Tbed3(cnt)=aspen.Tree.FindNode(path).Value;
    path=char(string('\Data\Blocks\BED4\Output\B_TEMP\MIXED\')+string(cnt));
    Tbed4(cnt)=aspen.Tree.FindNode(path).Value;
    path=char('\Data\Blocks\BED1\Output\B_MOLEFRAC\MIXED\'+string(cnt)+'\NH3');
    Xbed1(cnt)=aspen.Tree.FindNode(path).Value;
    path=char('\Data\Blocks\BED2\Output\B_MOLEFRAC\MIXED\'+string(cnt)+'\NH3');
    Xbed2(cnt)=aspen.Tree.FindNode(path).Value;
    path=char('\Data\Blocks\BED3\Output\B_MOLEFRAC\MIXED\'+string(cnt)+'\NH3');
    Xbed3(cnt)=aspen.Tree.FindNode(path).Value;
    path=char('\Data\Blocks\BED4\Output\B_MOLEFRAC\MIXED\'+string(cnt)+'\NH3');
    Xbed4(cnt)=aspen.Tree.FindNode(path).Value;
end
phy1=aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Output\STREAMFRAC\F2').Value;
phy2=aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Output\STREAMFRAC\F3').Value;
phy3=aspen.Tree.FindNode('\Data\Blocks\SPLIT1\Output\STREAMFRAC\F4').Value;
% Plotting the Temp vs Conc Profile for each bed
hold on
plot(Xbed1*100,Tbed1,'b-',Xbed2*100,Tbed2,'b-.',Xbed3*100,Tbed3,'b--',...
    Xbed4*100,Tbed4,'b:','lineWidth',2.5)
title(char(['       phy1='+string(phy1)+',  phy2='+string(phy2)+',  phy3='+string(phy3);...
    'Bed1: solid L., Bed2: dash/dot L., Bed3: dash L., Bed4: dot L.']))
                                                                               
